LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.Numeric_std.all;
use IEEE.std_logic_unsigned.all;
use IEEE.std_logic_arith.all;

ENTITY LimitRinging IS
PORT
	(
			reset 				: in STD_LOGIC;
			clk 				: in STD_LOGIC;
			InSignal			: in STD_LOGIC;
			OutSignal			: out STD_LOGIC
	);
END LimitRinging;

architecture basic of LimitRinging is

signal Mem : std_logic_vector(9 downto 0);

begin

process(Reset, Clk, InSignal)
	begin
	if Reset = '1' then
		Mem <= (OTHERS => '0');
	elsif Rising_edge(clk) then
		Mem <= Mem(Mem'LENGTH-2 downto 0) & InSignal;
	end if;
end process;	

gen_vout : PROCESS(clk, Mem)
  BEGIN
	if Rising_edge(clk) then
		if Mem = "0000000000" then
			OutSignal <= '0';
		elsif Mem = "1111111111" then
			OutSignal <= '1';
		end if;
	end if;
END PROCESS;

--gen_vout: PROCESS(Mem)
--    VARIABLE count : std_logic_vector(3 downto 0);
--    BEGIN
--    	count := (OTHERS => '0');
--        FOR i IN Mem'RANGE LOOP
--            count := count + Mem(i);
--        END LOOP;
--        
--		if count > std_logic_vector(TO_UNSIGNED(Mem'LENGTH/2,count'LENGTH)) then
--			OutSignal <= '1';
--		else
--			OutSignal <= '0';
--		end if;
--		
--END PROCESS gen_vout;

end architecture basic;



entity LimitRinging_tb is
end;

LIBRARY ieee;
USE ieee.std_logic_1164.all;
USE ieee.Numeric_std.all;
--use STD.TEXTIO.all;
--use IEEE.STD_LOGIC_TEXTIO.all;


architecture Bench of LimitRinging_tb is

    
signal Reset 							: STD_LOGIC;
signal Clk 								: STD_LOGIC;
signal InSignal						: STD_LOGIC;
signal OutSignal					: STD_LOGIC;           
constant ONE_CYCLE_TIME 	: integer 	:= 10;
constant ONE_CYCLE 				: time 			:= 10 NS;
constant NBR_CYCLE				: integer 	:= 1000;
  
begin

      --Reset 				: in STD_LOGIC;
			--Clk 				: in STD_LOGIC;
			--InSignal			: in STD_LOGIC;
			--OutSignal			: out STD_LOGIC           

  uut: entity work.LimitRinging
   
  port map (
    Reset 		 => Reset 		 ,
    Clk 			 => Clk 			 ,
    InSignal	 => InSignal	 ,
    OutSignal  => OutSignal  
  );

  Clock_proc: process
  begin
    while Now <= NBR_CYCLE*ONE_CYCLE loop
      Clk <= '0';
      wait for ONE_CYCLE/2;
      Clk <= '1';
      wait for ONE_CYCLE/2;
    end loop;
    wait;
  end process;


	process
	begin
		wait for ONE_CYCLE/2;
		Reset 		<= '1';								
    InSignal	<= '0';		
  			
		wait for ONE_CYCLE;
		Reset 		<= '0';	
		InSignal	<= '1';	
                      
                           
    wait for 20*ONE_CYCLE;
    Reset 		<= '0';	
		InSignal	<= '0';	
    
    wait for 20*ONE_CYCLE;
    
    wait;  
	end process;
	
end architecture Bench;



